# font-in
A better font extractor and installer for bulk fonts in one archive.

### font-in installs all the 

# Installation

```
pip install fontin
```

# How to use
To start using it, open command prompt in the folder which has archive of fonts (For example: Downloads). This can be done by simply changing the path in the file explorer to cmd.
Run it by typing ```fontin``` in cmd and then follow along.

# Features

Automatically show all zips in the directory so it's easier for the user to choose.

Automates the task of installing every variant of the font.

Very fast.

# How to contribute

You can simply help contribute by opening an issue whenever you find a bug. 

You can also contribute by forking this repository and then opening a pull request.